Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(170)

Unified Diff: ui/aura/mus/window_manager_delegate.h

Issue 2470963002: Makes it possible for clients to directly create WindowTreeHostMus (Closed)
Patch Set: nuke comment Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/aura/mus/mus_types.h ('k') | ui/aura/mus/window_mus.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/mus/window_manager_delegate.h
diff --git a/ui/aura/mus/window_manager_delegate.h b/ui/aura/mus/window_manager_delegate.h
index c21382530895c45d3a85649b2c24e1fbaa25f83e..478ce90f57494bb80a444a8afe5372f05a115dc1 100644
--- a/ui/aura/mus/window_manager_delegate.h
+++ b/ui/aura/mus/window_manager_delegate.h
@@ -37,6 +37,7 @@ class Event;
namespace aura {
class Window;
+class WindowTreeHostMus;
// See the mojom with the same name for details on the functions in this
// interface.
@@ -103,10 +104,11 @@ class AURA_EXPORT WindowManagerDelegate {
const std::set<Window*>& client_windows,
bool janky) = 0;
- // Called when a display is added. |window| is the root of the window tree for
- // the specified display.
- virtual void OnWmNewDisplay(Window* window,
- const display::Display& display) = 0;
+ // Called when a display is added. |window_tree_host| is the WindowTreeHost
+ // for the new display.
+ virtual void OnWmNewDisplay(
+ std::unique_ptr<WindowTreeHostMus> window_tree_host,
+ const display::Display& display) = 0;
// Called when a display is removed. |window| is the root of the display.
virtual void OnWmDisplayRemoved(Window* window) = 0;
« no previous file with comments | « ui/aura/mus/mus_types.h ('k') | ui/aura/mus/window_mus.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698